@@ -12,7 +12,7 @@
 #'
 #' The only exception is the `ggcorrmat()` function. But, if a data frame is
 #' what you want, you shouldn't be using `ggcorrmat()` anyway. You can use
-#' `correlation::correlation()` function which provides tidy data frames by
+#' [`correlation::correlation()`] function which provides tidy data frames by
 #' default.
 #'
 #' @returns
@@ -21,7 +21,6 @@
 #' The exact details included will depend on the function.
 #'
 #' @param p A plot from `{ggstatsplot}` package
-#' @param ... Ignored
 #'
 #' @autoglobal
 #'
@@ -46,27 +45,45 @@
 #'
 #' extract_stats(p1)
 #'
-#' extract_stats(p2[[1L]])
-#' extract_stats(p2[[2L]])
+#' extract_stats(p2)
 #' @export
-extract_stats <- function(p, ...) {
+extract_stats <- function(p) {
+  if (inherits(p, "patchwork")) purrr::map(.extract_plots(p), .extract_stats) else .extract_stats(p)
+}
+
+.extract_plots <- function(p) purrr::map(seq_along(p), ~ purrr::pluck(p, .x))
+
+.pluck_plot_env <- function(p, data) purrr::pluck(p, "plot_env", data)
+
+.extract_stats <- function(p) {
   # styler: off
-  list(
-    subtitle_data             = tryCatch(p$plot_env$subtitle_df,    error = function(e) NULL),
-    caption_data              = tryCatch(p$plot_env$caption_df,     error = function(e) NULL),
-    pairwise_comparisons_data = tryCatch(p$plot_env$mpc_df,         error = function(e) NULL),
-    descriptive_data          = tryCatch(p$plot_env$descriptive_df, error = function(e) NULL),
-    one_sample_data           = tryCatch(p$plot_env$onesample_df,   error = function(e) NULL),
-    tidy_data                 = tryCatch(p$plot_env$tidy_df,        error = function(e) NULL),
-    glance_data               = tryCatch(p$plot_env$glance_df,      error = function(e) NULL)
-  )
+  structure(list(
+    subtitle_data             = .pluck_plot_env(p, "subtitle_df"),
+    caption_data              = .pluck_plot_env(p, "caption_df"),
+    pairwise_comparisons_data = .pluck_plot_env(p, "mpc_df"),
+    descriptive_data          = .pluck_plot_env(p, "descriptive_df"),
+    one_sample_data           = .pluck_plot_env(p, "onesample_df"),
+    tidy_data                 = .pluck_plot_env(p, "tidy_df"),
+    glance_data               = .pluck_plot_env(p, "glance_df")
+  ), class = c("ggstatsplot_stats", "list"))
   # styler: on
 }
 
+
+
+# function factory to extract particular kind of stats data
+.extract_stats_data <- function(data_component) {
+  function(p) {
+    dat <- extract_stats(p)
+    .pluck_expression <- function(x) purrr::pluck(x, data_component, "expression", 1L)
+    if (inherits(dat, "ggstatsplot_stats")) .pluck_expression(dat) else purrr::map(dat, .pluck_expression)
+  }
+}
+
 #' @rdname extract_stats
 #' @export
-extract_subtitle <- function(p) purrr::pluck(extract_stats(p), "subtitle_data", "expression", 1L)
+extract_subtitle <- .extract_stats_data("subtitle_data")
 
 #' @rdname extract_stats
 #' @export
-extract_caption <- function(p) purrr::pluck(extract_stats(p), "caption_data", "expression", 1L)
+extract_caption <- .extract_stats_data("caption_data")
