@@ -36,19 +36,16 @@ descriptive_data <- function(
 #' @title A data frame with chi-squared test results
 #' @autoglobal
 #' @noRd
-onesample_data <- function(data, x, y, digits = 2L, ...) {
-  full_join(
-    # descriptive summary
-    x = .cat_counter(data, {{ y }}) %>%
-      mutate(N = paste0("(n = ", .prettyNum(counts), ")")),
-    # proportion test results
-    y = group_by(data, {{ y }}) %>%
-      group_modify(.f = ~ .chisq_test_safe(., {{ x }})) %>%
-      ungroup(),
-    by = as_name(ensym(y))
-  ) %>%
+onesample_data <- function(data, x, y, digits = 2L, ratio = NULL, ...) {
+  grouped_chi_squared_summary <- group_by(data, {{ y }}) %>%
+    group_modify(.f = ~ .chisq_test_safe(., {{ x }}, ratio)) %>%
+    ungroup()
+  descriptive_summary <- .cat_counter(data, {{ y }}) %>% mutate(N = paste0("(n = ", .prettyNum(counts), ")"))
+
+  full_join(descriptive_summary, grouped_chi_squared_summary, by = as_name(ensym(y))) %>%
     rowwise() %>%
     mutate(
+      # nolint next: line_length_linter.
       .label = glue("list(~chi['gof']^2~({df})=={format_value(statistic, digits)}, ~italic(p)=='{format_value(p.value, digits)}', ~italic(n)=='{.prettyNum(counts)}')"),
       .p.label = glue("list(~italic(p)=='{format_value(p.value, digits)}')")
     ) %>%
@@ -57,25 +54,19 @@ onesample_data <- function(data, x, y, digits = 2L, ...) {
 
 
 #' Safer version of chi-squared test that returns `NA`s
-#' Needed to work with `group_modify()` since it will not work when `NULL` is returned
+#' Needed to work with `dplyr::group_modify()` since it will not work when `NULL` is returned.
 #' @autoglobal
 #' @noRd
-.chisq_test_safe <- function(data, x, ...) {
-  xtab <- table(pull(data, {{ x }}))
-
-  result <- tryCatch(
-    expr = parameters::model_parameters(suppressWarnings(stats::chisq.test(xtab))),
-    error = function(e) NULL
+.chisq_test_safe <- function(data, x, ratio) {
+  tryCatch(
+    suppressWarnings(contingency_table(data, x, ratio = ratio)),
+    error = function(e) {
+      tibble(
+        statistic = NA_real_, p.value = NA_real_, df = NA_real_,
+        method = "Chi-squared test for given probabilities"
+      )
+    }
   )
-
-  if (is.null(result)) {
-    tibble(
-      statistic = NA_real_, p.value = NA_real_, df = NA_real_,
-      method = "Chi-squared test for given probabilities"
-    )
-  } else {
-    insight::standardize_names(result, style = "broom") %>% as_tibble()
-  }
 }
 
 
